@@ -1,4 +1,6 @@
 import os
+import pickle
+import warnings
 
 import fsspec
 
@@ -43,6 +45,25 @@ class Artifact(Base, TagMixin):
             project_name, self.id, experiment_id=experiment_id
         )
 
+    @failsafe
+    def get_data(self, unpickle=False):
+        """Loads the data associated with this artifact and
+        unpickles if needed.
+
+        Parameters
+        ----------
+        unpickle : bool, optional
+            Flag indicating whether artifact data must be
+            unpickled. Will be returned as bytes by default.
+        """
+        project_name, experiment_id = self.parent._get_identifiers()
+
+        data = self.repository.get_artifact_data(project_name, self.id, experiment_id=experiment_id)
+        if unpickle:
+            data = pickle.loads(data)
+
+        return data
+
     @failsafe
     def download(self, location=None, name=None):
         """Download this artifact's data.
@@ -90,6 +111,10 @@ class Artifact(Base, TagMixin):
     @property
     def data(self):
         """Get the artifact's raw data."""
+        warnings.warn(
+            "`data` is deprecated, use `get_data()` instead",
+            DeprecationWarning,
+        )
         if self._data is None:
             self._get_data()
 
